YARP 2.2.0 (2008-04-09)                                                {#v2_2_0}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.9...v2.2.0`):

```
    43	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    14	YARP Developers <yarp0-devel@lists.sourceforge.net>
     6	Alessandro Scalzo <alessandro.scalzo@iit.it>
     2	Giacomo Spigler <spiglerg@gmail.com>
     1	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     1	Giorgio Metta <giorgio.metta@iit.it>
```
